##################################################################################################################
#
# Search-E-Mail-Addresses
#
# This script searches the entire directory for a defined e-mail address. It searches in user mailboxes,
# public folders and distribution groups and offers information to find the object.
#
# Example: .\Search-E-Mail-Addresses
#
# Dependencies:
# - Exchange Management Powershell snapin is installed
# - Powershell Module activedirectory is installed
#
# You are allowed to change the script to your needs. But please don't remove the origin and author information.
# Origin:		www.fam-dueck.de
#
# Author:       Eduard Dueck
#
# Date:         19.01.2017
#
# Changed by:   Eduard Dueck
#
# Date:         19.01.2017
#
# Version:      1.0
#
# Changelog:    1.0 - Initial development
#
##################################################################################################################

Add-pssnapin Microsoft.Exchange.Management.Powershell.SnapIn
Import-Module activedirectory

# You need to set this variale. This is your search string
$emailaddress = "John.Doe@"


#### Don't change anything below here ############################################################################
cls
$found = 0
$emailaddress = $("*"+$emailaddress+"*")


#search mailboxes
$mbxs = Get-Mailbox -Filter * -ResultSize unlimited
foreach ($mbx in $mbxs)
{
    $mbxaddresses = $mbx.EmailAddresses
    foreach ($mbxaddress in $mbxaddresses)
    {
        if($mbxaddress -like $emailaddress)
        {
            $found = 1
        }
    }
    if($found)
    {
        write-host -ForegroundColor Yellow User
        write-host $mbx.SamAccountName
        write-host $mbx.OrganizationalUnit
        write-host $mbxaddress
        $found = 0
    }
    
}


#search public folders
$pfs = Get-PublicFolder -Recurse -ResultSize unlimited
foreach ($pf in $pfs)
{
    if($pf.MailEnabled)
    {
        $mpfs = Get-MailPublicFolder $pf #| Select Displayname, Emailaddresses
        foreach ($mpf in $mpfs)
        {
            $MPFEmailAddresses = $mpf.EmailAddresses.ToStringArray()
            foreach($MPFEmailAddress in $MPFEmailAddresses)
            {
                if($MPFEmailAddress.ToString() -like $emailaddress)
                {
                    $found = 1
                }
            }
            if($found)
            {
                write-host -ForegroundColor Yellow PublicFolder
                write-host $pf.Identity
                write-host $mpf.EmailAddresses
                $found = 0
            }
        }
    }
}


#search distribution groups
$dstgrps = Get-DistributionGroup -ResultSize unlimited
foreach ($dstgrp in $dstgrps)
{
    $dstgrpaddrs = $dstgrp.EmailAddresses
    foreach ($dstgrpaddr in $dstgrpaddrs)
    {
        if($dstgrpaddr.SmtpAddress -like $emailaddress)
        {
            $found = 1
        }
    }
    if($found)
    {
        write-host -ForegroundColor Yellow DistributionGroup
        write-host $dstgrp.Identity
        write-host $dstgrp.EmailAddresses
        $found = 0
    }
}